@@ -19,11 +19,23 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #include "funcdef.h"
 #include <stdio.h>
 
-#define obstack_chunk_alloc ck_malloc
+#include "sysdef.h"
+
+#ifdef _DEBUG_MALLOC_INC
+static void
+local_free (p)
+     void * p;
+{
+  free (p);
+}
+#define obstack_chunk_free local_free
+#else /* ndef _DEBUG_MALLOC_INC */
 #define obstack_chunk_free free
+#endif /* ndef _DEBUG_MALLOC_INC */
+
+#define obstack_chunk_alloc ck_malloc
 #include "obstack.h"
 
-#include "sysdef.h"
 #include "global.h"
 #include "node.h"
 #include "eval.h"
