@@ -579,7 +579,12 @@ decomp (r, c, cell)
   extern char *bname[];
 
   if (!cell)
-    return "";
+    {
+      str = ck_malloc (1);
+      str[0] = '\0';
+      save_decomp = (VOIDSTAR) str;
+      return str;
+    }
   decomp_row = r;
   decomp_col = c;
   if (cell->cell_formula == 0)
