@@ -880,7 +880,7 @@ DEFUN ("edit-cell", FDedit_cell, FAedit_cell, edit_cell)
 
 DEFUN ("set-cell", FDset_cell, FAset_cell, edit_cell)
 #ifdef FUNC_ARG_STRINGS
-"sSet %c to? ", 
+"$'Set %c to? ", 
 #endif
 #ifdef DOC_STRINGS
 "Assign FORMULA to the current cell.",
@@ -1200,7 +1200,7 @@ DEFUN_5 ("set-cell-font", FDset_cell_font, FAset_cell_font,
 	 DFset_cell_font, set_region_font)
 #ifdef FUNC_ARG_STRINGS
 ".'",
-"sSet %0 font to? ",
+"wSet %0 font to? ",
 "dScale? (ratio to the default point size e.g. 1.3) ",
 #endif
 #ifdef FUNC_INIT_CODE
@@ -1225,7 +1225,7 @@ DEFUN_5 ("set-region-font", FDset_region_font, FAset_region_font,
 	 DFset_region_font, set_region_font)
 #ifdef FUNC_ARG_STRINGS
 "rSet font for what region? ",
-"sSet %0 font to? ",
+"wSet %0 font to? ",
 "dPoint size? ",
 #endif
 #ifdef FUNC_INIT_CODE
@@ -1563,7 +1563,7 @@ DEFUN ("display-error-msg",
 #ifdef DOC_STRINGS
 "Display an error message for the user.",
 "The message vanishes as soon as the user types the next character of input",
-"of after a brief timeout.",
+"or after a brief timeout.",
 #endif
 
 
@@ -1841,7 +1841,7 @@ DEFUN ("set-default-format",
 DEFUN ("set-default-font",
        FDset_default_font, FAset_default_font, set_default_font)
 #ifdef FUNC_ARG_STRINGS
-"sSet default font to? ",
+"wSet default font to? ",
 "dPoint size? (e.g. 1.3) ",
 #endif
 #ifdef DOC_STRINGS
@@ -1861,15 +1861,15 @@ DEFUN_5 ("define-user-format",
 	 FDdefine_usr_fmt, FAdefine_usr_fmt, DFdefine_usr_fmt, define_usr_fmt)
 #ifdef FUNC_ARG_STRINGS
 "N[1,16]Define format [1-16]? ",
-"sPositive header? ",
-"sNegative header? ",
-"sPositive trailer? ",
-"sNegative trailer? ",
-"sRepresentation of zero? ",
-"sComma? ",
-"sDecimal point? ",
-"sPrecision [0-14 or `float']? ",
-"sScale-factor? ",
+"wPositive header? ",
+"wNegative header? ",
+"wPositive trailer? ",
+"wNegative trailer? ",
+"wRepresentation of zero? ",
+"wComma? ",
+"wDecimal point? ",
+"wPrecision [0-14 or `float']? ",
+"wScale-factor? ",
 #endif
 #ifdef FUNC_INIT_CODE
 0,
