@@ -53,7 +53,7 @@ char * formula_info[] =
 "",
 "val1 = val2		#TRUE if val1 and val2 can be considered equal.",
 "			#FALSE otherwise",
-"val1 != val2		Equivelent to !(val1=val2)",
+"val1 != val2		Equivalent to !(val1=val2)",
 "",
 "str1 & str2		Text concatination.",
 "",
@@ -376,7 +376,7 @@ char * formula_info[] =
 "negate",
 "Negation				negate(num)",
 "",
-"Equivelent to `0 - NUM'.",
+"Equivalent to `0 - NUM'.",
 0,
 
 
@@ -474,7 +474,7 @@ char * formula_info[] =
 "",
 "Returns `sqrt (NUM1 * NUM1 + NUM2 * NUM2)'.  ",
 "",
-"Calling `hypot' may succeed in cases when the equivelent expression",
+"Calling `hypot' may succeed in cases when the equivalent expression",
 "might underflow or overflow.",
 0,
 
@@ -1006,7 +1006,7 @@ char * formula_info[] =
 "^W --  print-wallchart",
 "	Write a list of keybindings to a file.",
 0,
-"graphing"
+"graphing",
 "",
 "[graph-presets-verbosely]	--  Reset graphing parameters to default values.",
 "[graph-clear-verbosely]	--  Clear the datasets of their assigned ranges.",
@@ -1014,7 +1014,7 @@ char * formula_info[] =
 "[graph-set-data]	--  Assign a range of data to a dataset in the graph.",
 "[graph-verify]	--  Verify graph parameters.",
 "[graph-plot]	--  Plot with the current parameters.",
-""
+"",
 "The following control optional parameters:",
 "",
 "[graph-x-axis]	--  Define parameters relating the X axis.",
@@ -1277,7 +1277,7 @@ char * formula_info[] =
 "",
 "",
 "",
-"			    Editting cells",
+"			    Editing cells",
 "",
 "Edit cell			[edit-cell]",
 "Set region formula		[set-region-formula]",
@@ -1290,7 +1290,7 @@ char * formula_info[] =
 "From the main keymap, typing almost any printable character begins ",
 "to edit the value of a cell.",
 "",
-"These commands provide efficent motion while editting cells:",
+"These commands provide efficent motion while editing cells:",
 "[[read-formula]]",
 "Next edit			[next-edit]",
 "Next edit-set			[next-edit-set]",
@@ -1310,7 +1310,7 @@ char * formula_info[] =
 "Auto move no motion		[auto-move-no-motion]",
 "",
 "",
-"		      Editting in the input area",
+"		      Editing in the input area",
 "",
 "Toggle overwrite		[toggle-overwrite]",
 "Beginning of line		[beginning-of-line]",
