@@ -1,5 +1,6 @@
 
-/*  A Bison parser, made from ./getdate.y  */
+/*  A Bison parser, made from /phydeaux/ni/lord/unsupported/oleo/getdate.y with Bison version GNU Bison version 1.22
+  */
 
 #define YYBISON 1  /* Identify Bison output.  */
 
@@ -17,9 +18,9 @@
 #define	tZONE	269
 #define	tDST	270
 
-#line 1 "./getdate.y"
+#line 1 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 
-/* $Revision: 2.1 $
+/* $Revision: 1.1 $
 **
 **  Originally written by Steven M. Bellovin <smb@research.att.com> while
 **  at the University of North Carolina at Chapel Hill.  Later tweaked by
@@ -118,7 +119,7 @@ extern struct tm	*localtime();
 
 #if	!defined(lint) && !defined(SABER)
 static char RCS[] =
-	"$Header: str2date.y,v 2.1 90/09/06 08:15:06 cronan Exp $";
+	"$Header: /rel/cvsfiles/unsupported/oleo/getdate.y,v 1.1 94/06/03 16:18:42 lord Exp $";
 #endif	/* !defined(lint) && !defined(SABER) */
 
 
@@ -179,7 +180,7 @@ static time_t	gtdRelMonth;
 static time_t	gtdRelSeconds;
 
 
-#line 163 "./getdate.y"
+#line 163 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 typedef union {
     time_t		Number;
     enum _MERIDIAN	Meridian;
@@ -203,9 +204,11 @@ typedef
 
 #include <stdio.h>
 
+#ifndef __cplusplus
 #ifndef __STDC__
 #define const
 #endif
+#endif
 
 
 
@@ -253,8 +256,6 @@ static const short gtdprhs[] = {     0,
     98,   100,   103,   106,   108,   111,   114,   116,   118,   119
 };
 
-#endif
-
 static const short gtdrhs[] = {    -1,
     19,    20,     0,    21,     0,    22,     0,    24,     0,    23,
      0,    25,     0,    27,     0,    13,     7,     0,    13,    16,
@@ -270,6 +271,8 @@ static const short gtdrhs[] = {    -1,
     13,    10,     0,    10,     0,    13,     0,     0,     7,     0
 };
 
+#endif
+
 #if YYDEBUG != 0
 static const short gtdrline[] = { 0,
    177,   178,   181,   184,   187,   190,   193,   196,   199,   205,
@@ -345,7 +348,7 @@ static const short gtdcheck[] = {     0,
     46
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-#line 3 "/afs/andrew/usr11/lord//lib/bison.simple"
+#line 3 "/usr/unsupported/lib/bison.simple"
 
 /* Skeleton output parser for bison,
    Copyright (C) 1984, 1989, 1990 Bob Corbett and Richard Stallman
@@ -369,7 +372,7 @@ static const short gtdcheck[] = {     0,
 #ifdef __GNUC__
 #define alloca __builtin_alloca
 #else /* not GNU C.  */
-#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc)
+#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi)
 #include <alloca.h>
 #else /* not sparc */
 #if defined (MSDOS) && !defined (__TURBOC__)
@@ -378,6 +381,16 @@ static const short gtdcheck[] = {     0,
 #if defined(_AIX)
 #include <malloc.h>
  #pragma alloca
+#else /* not MSDOS, __TURBOC__, or _AIX */
+#ifdef __hpux
+#ifdef __cplusplus
+extern "C" {
+void *alloca (unsigned int);
+};
+#else /* not __cplusplus */
+void *alloca ();
+#endif /* not __cplusplus */
+#endif /* __hpux */
 #endif /* not _AIX */
 #endif /* not MSDOS, or __TURBOC__ */
 #endif /* not sparc.  */
@@ -471,6 +484,11 @@ int gtddebug;			/*  nonzero means print parse trace	*/
 #ifndef YYMAXDEPTH
 #define YYMAXDEPTH 10000
 #endif
+
+/* Prevent warning if -Wstrict-prototypes.  */
+#ifdef __GNUC__
+int gtdparse (void);
+#endif
 
 #if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
 #define __gtd_bcopy(FROM,TO,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
@@ -511,7 +529,7 @@ __gtd_bcopy (char *from, char *to, int count)
 #endif
 #endif
 
-#line 169 "/afs/andrew/usr11/lord//lib/bison.simple"
+#line 184 "/usr/unsupported/lib/bison.simple"
 int
 gtdparse()
 {
@@ -520,7 +538,7 @@ gtdparse()
   register short *gtdssp;
   register YYSTYPE *gtdvsp;
   int gtderrstatus;	/*  number of tokens to shift before error messages enabled */
-  int gtdchar1;		/*  lookahead token as an internal (translated) token number */
+  int gtdchar1 = 0;		/*  lookahead token as an internal (translated) token number */
 
   short	gtdssa[YYINITDEPTH];	/*  the state stack			*/
   YYSTYPE gtdvsa[YYINITDEPTH];	/*  the semantic value stack		*/
@@ -599,13 +617,20 @@ gtdnewstate:
 #ifdef gtdoverflow
       /* Each stack pointer address is followed by the size of
 	 the data in use in that stack, in bytes.  */
+#ifdef YYLSP_NEEDED
+      /* This used to be a conditional around just the two extra args,
+	 but that might be undefined if gtdoverflow is a macro.  */
       gtdoverflow("parser stack overflow",
 		 &gtdss1, size * sizeof (*gtdssp),
 		 &gtdvs1, size * sizeof (*gtdvsp),
-#ifdef YYLSP_NEEDED
 		 &gtdls1, size * sizeof (*gtdlsp),
-#endif
 		 &gtdstacksize);
+#else
+      gtdoverflow("parser stack overflow",
+		 &gtdss1, size * sizeof (*gtdssp),
+		 &gtdvs1, size * sizeof (*gtdvsp),
+		 &gtdstacksize);
+#endif
 
       gtdss = gtdss1; gtdvs = gtdvs1;
 #ifdef YYLSP_NEEDED
@@ -766,7 +791,8 @@ gtddefault:
 /* Do a reduction.  gtdn is the number of a rule to reduce with.  */
 gtdreduce:
   gtdlen = gtdr2[gtdn];
-  gtdval = gtdvsp[1-gtdlen]; /* implement default value of the action */
+  if (gtdlen > 0)
+    gtdval = gtdvsp[1-gtdlen]; /* implement default value of the action */
 
 #if YYDEBUG != 0
   if (gtddebug)
@@ -787,37 +813,37 @@ gtdreduce:
   switch (gtdn) {
 
 case 3:
-#line 181 "./getdate.y"
+#line 181 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdHaveTime++;
 	;
     break;}
 case 4:
-#line 184 "./getdate.y"
+#line 184 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdHaveZone++;
 	;
     break;}
 case 5:
-#line 187 "./getdate.y"
+#line 187 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdHaveDate++;
 	;
     break;}
 case 6:
-#line 190 "./getdate.y"
+#line 190 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdHaveDay++;
 	;
     break;}
 case 7:
-#line 193 "./getdate.y"
+#line 193 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdHaveRel++;
 	;
     break;}
 case 9:
-#line 199 "./getdate.y"
+#line 199 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdHour = gtdvsp[-1].Number;
 	    gtdMinutes = 0;
@@ -826,7 +852,7 @@ case 9:
 	;
     break;}
 case 10:
-#line 205 "./getdate.y"
+#line 205 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdHour = gtdvsp[-3].Number;
 	    gtdMinutes = gtdvsp[-1].Number;
@@ -835,7 +861,7 @@ case 10:
 	;
     break;}
 case 11:
-#line 211 "./getdate.y"
+#line 211 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdHour = gtdvsp[-3].Number;
 	    gtdMinutes = gtdvsp[-1].Number;
@@ -845,7 +871,7 @@ case 11:
 	;
     break;}
 case 12:
-#line 218 "./getdate.y"
+#line 218 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdHour = gtdvsp[-5].Number;
 	    gtdMinutes = gtdvsp[-3].Number;
@@ -854,7 +880,7 @@ case 12:
 	;
     break;}
 case 13:
-#line 224 "./getdate.y"
+#line 224 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdHour = gtdvsp[-5].Number;
 	    gtdMinutes = gtdvsp[-3].Number;
@@ -865,56 +891,56 @@ case 13:
 	;
     break;}
 case 14:
-#line 234 "./getdate.y"
+#line 234 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdTimezone = gtdvsp[0].Number;
 	    gtdDSTmode = DSToff;
 	;
     break;}
 case 15:
-#line 238 "./getdate.y"
+#line 238 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdTimezone = gtdvsp[0].Number;
 	    gtdDSTmode = DSTon;
 	;
     break;}
 case 16:
-#line 243 "./getdate.y"
+#line 243 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdTimezone = gtdvsp[-1].Number;
 	    gtdDSTmode = DSTon;
 	;
     break;}
 case 17:
-#line 249 "./getdate.y"
+#line 249 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdDayOrdinal = 1;
 	    gtdDayNumber = gtdvsp[0].Number;
 	;
     break;}
 case 18:
-#line 253 "./getdate.y"
+#line 253 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdDayOrdinal = 1;
 	    gtdDayNumber = gtdvsp[-1].Number;
 	;
     break;}
 case 19:
-#line 257 "./getdate.y"
+#line 257 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdDayOrdinal = gtdvsp[-1].Number;
 	    gtdDayNumber = gtdvsp[0].Number;
 	;
     break;}
 case 20:
-#line 263 "./getdate.y"
+#line 263 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdMonth = gtdvsp[-2].Number;
 	    gtdDay = gtdvsp[0].Number;
 	;
     break;}
 case 21:
-#line 267 "./getdate.y"
+#line 267 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdMonth = gtdvsp[-4].Number;
 	    gtdDay = gtdvsp[-2].Number;
@@ -922,7 +948,7 @@ case 21:
 	;
     break;}
 case 22:
-#line 272 "./getdate.y"
+#line 272 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    /* ISO 8601 format.  gtdgtd-mm-dd.  */
 	    gtdYear = gtdvsp[-2].Number;
@@ -931,14 +957,14 @@ case 22:
 	;
     break;}
 case 23:
-#line 278 "./getdate.y"
+#line 278 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdMonth = gtdvsp[-1].Number;
 	    gtdDay = gtdvsp[0].Number;
 	;
     break;}
 case 24:
-#line 282 "./getdate.y"
+#line 282 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdMonth = gtdvsp[-3].Number;
 	    gtdDay = gtdvsp[-2].Number;
@@ -946,14 +972,14 @@ case 24:
 	;
     break;}
 case 25:
-#line 287 "./getdate.y"
+#line 287 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdMonth = gtdvsp[0].Number;
 	    gtdDay = gtdvsp[-1].Number;
 	;
     break;}
 case 26:
-#line 291 "./getdate.y"
+#line 291 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdMonth = gtdvsp[-1].Number;
 	    gtdDay = gtdvsp[-2].Number;
@@ -961,68 +987,68 @@ case 26:
 	;
     break;}
 case 27:
-#line 298 "./getdate.y"
+#line 298 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdRelSeconds = -gtdRelSeconds;
 	    gtdRelMonth = -gtdRelMonth;
 	;
     break;}
 case 29:
-#line 305 "./getdate.y"
+#line 305 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdRelSeconds += gtdvsp[-1].Number * gtdvsp[0].Number * 60L;
 	;
     break;}
 case 30:
-#line 308 "./getdate.y"
+#line 308 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdRelSeconds += gtdvsp[-1].Number * gtdvsp[0].Number * 60L;
 	;
     break;}
 case 31:
-#line 311 "./getdate.y"
+#line 311 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdRelSeconds += gtdvsp[0].Number * 60L;
 	;
     break;}
 case 32:
-#line 314 "./getdate.y"
+#line 314 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdRelSeconds += gtdvsp[-1].Number;
 	;
     break;}
 case 33:
-#line 317 "./getdate.y"
+#line 317 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdRelSeconds += gtdvsp[-1].Number;
 	;
     break;}
 case 34:
-#line 320 "./getdate.y"
+#line 320 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdRelSeconds++;
 	;
     break;}
 case 35:
-#line 323 "./getdate.y"
+#line 323 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdRelMonth += gtdvsp[-1].Number * gtdvsp[0].Number;
 	;
     break;}
 case 36:
-#line 326 "./getdate.y"
+#line 326 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdRelMonth += gtdvsp[-1].Number * gtdvsp[0].Number;
 	;
     break;}
 case 37:
-#line 329 "./getdate.y"
+#line 329 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdRelMonth += gtdvsp[0].Number;
 	;
     break;}
 case 38:
-#line 334 "./getdate.y"
+#line 334 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    if (gtdHaveTime && gtdHaveDate && !gtdHaveRel)
 		gtdYear = gtdvsp[0].Number;
@@ -1051,20 +1077,20 @@ case 38:
 	;
     break;}
 case 39:
-#line 362 "./getdate.y"
+#line 362 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdval.Meridian = MER24;
 	;
     break;}
 case 40:
-#line 365 "./getdate.y"
+#line 365 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 {
 	    gtdval.Meridian = gtdvsp[0].Meridian;
 	;
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 442 "/afs/andrew/usr11/lord//lib/bison.simple"
+#line 465 "/usr/unsupported/lib/bison.simple"
 
   gtdvsp -= gtdlen;
   gtdssp -= gtdlen;
@@ -1134,7 +1160,9 @@ gtderrlab:   /* here on detecting error */
 	  int x, count;
 
 	  count = 0;
-	  for (x = 0; x < (sizeof(gtdtname) / sizeof(char *)); x++)
+	  /* Start X at -gtdn if nec to avoid negative indexes in gtdcheck.  */
+	  for (x = (gtdn < 0 ? -gtdn : 0);
+	       x < (sizeof(gtdtname) / sizeof(char *)); x++)
 	    if (gtdcheck[x + gtdn] == x)
 	      size += strlen(gtdtname[x]) + 15, count++;
 	  msg = (char *) malloc(size + 15);
@@ -1145,7 +1173,8 @@ gtderrlab:   /* here on detecting error */
 	      if (count < 5)
 		{
 		  count = 0;
-		  for (x = 0; x < (sizeof(gtdtname) / sizeof(char *)); x++)
+		  for (x = (gtdn < 0 ? -gtdn : 0);
+		       x < (sizeof(gtdtname) / sizeof(char *)); x++)
 		    if (gtdcheck[x + gtdn] == x)
 		      {
 			strcat(msg, count == 0 ? ", expecting `" : " or `");
@@ -1257,7 +1286,7 @@ gtderrhandle:
   gtdstate = gtdn;
   goto gtdnewstate;
 }
-#line 370 "./getdate.y"
+#line 370 "/phydeaux/ni/lord/unsupported/oleo/getdate.y"
 
 
 /* Month and day table. */
