@@ -1040,7 +1040,7 @@ spew_gnuplot (fp, data_files, dir, dbase)
 		  free (wdf.gsf.names[x]);
 		ck_free (wdf.gsf.names);
 	      }
-	    fprintf (fp, "%s %s %s with %s",
+	    fprintf (fp, "%s %s title %s with %s",
 		     need_comma ? "," : "",
 		     graph_quoted_str (data_files [x].buf),
 		     graph_title [x].buf,
