@@ -152,8 +152,8 @@ void free ();
 #define STAT_USED      (5)	/* slots used right now */
 #define STATLENGTH     (6)	/* size of statistics block */
 #if STATLENGTH != HASH_STATLENGTH
-Panic ! Please make
-#include "stat.h" agree with previous definitions!
+Panic ! Please make this agree with previous definitions!
+#include "stat.h"
 #endif
 
 /* #define SUSPECT to do runtime checks */
