@@ -252,8 +252,12 @@ goto_char (n)
      int n;
 #endif
 {
-  if ((n < 0) || (n > (strlen (the_text.buf))))
-    io_error_msg ("Char out of range (%d)", n);
+  int len;
+  if (n < 0)
+    n = 0;
+  len = strlen(the_text.buf);
+  if (n > len)
+    n = len;
   the_cursor = n;
   io_move_cursor ();
 }
