@@ -12,13 +12,12 @@ but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with Oleo; see the file COPYING.  If not, write to
-the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
+You should have received a copy of the GNU General Public License along with
+Oleo; see the file COPYING.  If not, write to the Free Software Foundation, 675
+Mass Ave, Cambridge, MA 02139, USA.  */
 
 #include <stdio.h>
 #include <ctype.h>
-#include <math.h>
 #include "sysdef.h"
 #include "io-utils.h"
 #include "cell.h"
@@ -1317,7 +1316,8 @@ says_default (str)
   str += 3;
   while (*str && *key)
     {
-      if (tolower(*str) != *key)
+      int c = isupper (*str) ? tolower (*str) : *str;
+      if (c != *key)
 	return 0;
       ++key;
       ++str;
