@@ -163,6 +163,7 @@ name_of (foo)
 }
 
 static XrmDatabase rdb;
+static KeySym RetKeySym;
 
 #ifdef __STDC__
 void
@@ -202,6 +203,8 @@ get_x11_args (argc_p, argv)
   FD_SET (ConnectionNumber (theDisplay), &read_fd_set);
   FD_SET (ConnectionNumber (theDisplay), &exception_fd_set);
   
+  RetKeySym = XStringToKeysym("Return");
+
   /* Load the resource databases in a manner not unlike emacs :). */
   rdb = x_load_resources (theDisplay, 0, rdb_class_name);
   
@@ -622,7 +625,7 @@ io_col_to_input_pos (c)
   {
     int cpos;
     int max = iv->visibility_end - iv->visibility_begin + 1;
-    for (cpos = 1; cpos < max; ++cpos)
+    for (cpos = 1; cpos <= max; ++cpos)
       if (iv->input_metric (iv->input_area->buf + iv->visibility_begin, cpos)
 	  >= c)
 	break;
@@ -642,6 +645,9 @@ static int block_on_getch = 1;
 static char *input_buf = 0;
 static int input_buf_allocated = 0;
 static int chars_buffered = 0;
+static char *se_buf = 0;
+static int se_buf_allocated = 0;
+static int se_chars_buffered = 0;
 #define MAX_KEY_TRANSLATION	(1024)
 
 static XComposeStatus compose;
@@ -679,7 +685,70 @@ xio_scan_for_input (blockp)
 	io_redisp ();
       
       if (events_pending || blockp)
-	XNextEvent (thePort->dpy, &event_return);
+	{
+	  XNextEvent (thePort->dpy, &event_return);
+
+          if (event_return.xany.send_event)
+	    {
+	      /*
+	       * Allow other XClients to send oleo commands.
+	       */
+	      static KeySym se_keysym;
+
+	      switch (event_return.type)
+                {
+	          case KeyPress:
+                    /* Put keypress send_events aside until a <Return>. */
+	            if (se_chars_buffered + MAX_KEY_TRANSLATION 
+			  >= se_buf_allocated)
+	              {
+	                se_buf_allocated =
+		          2 * (se_buf_allocated
+		            ? se_buf_allocated
+		            : MAX_KEY_TRANSLATION);
+	                se_buf =
+		          (char *) ck_remalloc (se_buf, se_buf_allocated);
+	              }
+	            len = XLookupString (&event_return,
+			           se_buf + se_chars_buffered,
+			           MAX_KEY_TRANSLATION, &se_keysym, &compose);
+
+	            if ((len == 1) && (event_return.xkey.state & Mod1Mask))
+	              se_buf[se_chars_buffered] |= 0x80;
+
+	            if (se_keysym == RetKeySym)
+                      {
+			jmp_buf tmp_exception;
+
+			bcopy(error_exception, tmp_exception, sizeof(jmp_buf));
+		        se_buf[se_chars_buffered] = '\0';
+
+			if (setjmp (error_exception))
+			  {
+			    fprintf(stderr, "Error in send_event command: %s\n", se_buf);
+			    se_buf[0] = '\0';
+			    se_chars_buffered = 0;
+			    set_info (0);
+		            pop_unfinished_command ();
+			    bcopy(tmp_exception, error_exception, sizeof(jmp_buf));
+			    longjmp (error_exception, 1); /**/
+			  }
+			else
+			  {
+			    execute_command (se_buf);
+			    bcopy(tmp_exception, error_exception, sizeof(jmp_buf));
+			  }
+		        se_buf[0] = '\0';
+		        se_chars_buffered = 0;
+                      }
+		    else
+		      se_chars_buffered += len;
+	            break;
+	        }
+              events_pending = XPending (thePort->dpy);
+	      continue;
+            }
+	  }
       else
 	return;
       
@@ -2271,30 +2340,43 @@ xio_open_display ()
   
   thePort->screen = DefaultScreen (thePort->dpy);
   thePort->color_map = DefaultColormap (thePort->dpy, thePort->screen);
+
+  /* First try to allocate the color.  If that doesn't work, go ahead */
+  /* and set it to black on white.  (white and black are always in    */
+  /* the colormap, so if the color names are set with those values,   */
+  /* the first test should succeed.  This replaces a bunch of tests   */
+  /* that were in the 1.5 release.       PGA                          */
   
   if (default_fg_color_name && 
-      XParseColor (thePort->dpy, thePort->color_map, default_fg_color_name, &thePort->fg_color) &&
+      XParseColor (thePort->dpy, thePort->color_map, 
+                   default_fg_color_name, &thePort->fg_color) &&
       XAllocColor(thePort->dpy, thePort->color_map, &thePort->fg_color))
     thePort->fg_color_pixel = thePort->fg_color.pixel;
   else
-    if (default_fg_color_name && !stricmp (default_fg_color_name, "black"))
-      thePort->fg_color_pixel = BlackPixel (thePort->dpy, thePort->screen);
-    else
-      if (default_fg_color_name && !stricmp (default_fg_color_name, "white"))
-	thePort->fg_color_pixel = WhitePixel (thePort->dpy, thePort->screen);
-  
+    {
+    thePort->fg_color_pixel = BlackPixel (thePort->dpy, thePort->screen);
+    fprintf(stderr, "Unable to allocate colorcell for %s.  Using black instead.\n", default_fg_color_name);
+    }
+      	
   if (default_bg_color_name && 
       XParseColor (thePort->dpy, thePort->color_map,
 		   default_bg_color_name, &thePort->bg_color) &&
       XAllocColor(thePort->dpy, thePort->color_map, &thePort->bg_color))
     thePort->bg_color_pixel = thePort->bg_color.pixel;
   else
-    if (default_bg_color_name && !stricmp (default_bg_color_name, "black"))
-      thePort->bg_color_pixel = BlackPixel (thePort->dpy, thePort->screen);
-    else
-      if (default_bg_color_name && !stricmp (default_bg_color_name, "white"))
-	thePort->bg_color_pixel = WhitePixel (thePort->dpy, thePort->screen);
-  
+    {
+    thePort->bg_color_pixel = WhitePixel (thePort->dpy, thePort->screen);
+    fprintf(stderr, "Unable to allocate colorcell for %s.  Using white instead.\n", default_bg_color_name);
+    }
+    
+  /* May have a situation where could allocate one color, but not the other */
+  if (thePort->fg_color_pixel == thePort->bg_color_pixel)
+      {
+      thePort->fg_color_pixel = BlackPixel (thePort->dpy, thePort->screen);      	
+      thePort->bg_color_pixel = WhitePixel (thePort->dpy, thePort->screen);
+      fprintf(stderr, "Foreground and background are identical.  Using black on white.\n");
+      }
+      
   thePort->window =
     XCreateSimpleWindow (thePort->dpy, DefaultRootWindow (thePort->dpy),
 			 geom_x, geom_y, geom_w, geom_h,
@@ -2563,6 +2645,12 @@ set_x_default_point_size (l)
      int l;
 #endif
 {
+
+/* If the display is not open (ie, we're running on a non x screen, */
+/* silently return - allows stuff in startup file to work right.PGA */
+
+  if (!x11_opened) return;
+  
   if (l > 4)
     {
       cell_font_point_size = l;
