@@ -18,10 +18,20 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
 #include "funcdef.h"
 
-#define obstack_chunk_alloc ck_malloc
-#define obstack_chunk_free free
-#include "obstack.h"
 #include "sysdef.h"
+#ifndef _DEBUG_MALLOC_INC
+#define local_free free
+#else 
+static void
+local_free (p)
+     void * p;
+{
+  free (p);
+}
+#endif /* def _DEBUG_MALLOC_INC */
+#define obstack_chunk_alloc ck_malloc
+#define obstack_chunk_free local_free
+#include "obstack.h"
 #include "global.h"
 #include "cell.h"
 #include "ref.h"
@@ -472,6 +482,7 @@ static struct find *w_find;
 static struct find *h_find;
 static struct list *wids, *hgts;
 
+
 void 
 init_cells ()
 {
