@@ -1,5 +1,6 @@
 
-/*  A Bison parser, made from ./parse.y  */
+/*  A Bison parser, made from /phydeaux/ni/lord/unsupported/oleo/parse.y with Bison version GNU Bison version 1.22
+  */
 
 #define YYBISON 1  /* Identify Bison output.  */
 
@@ -26,7 +27,7 @@
 #define	L_NE	278
 #define	L_GE	279
 
-#line 1 "./parse.y"
+#line 1 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 
 /*	Copyright (C) 1990, 1992, 1993 Free Software Foundation, Inc.
 
@@ -45,7 +46,7 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with Oleo; see the file COPYING.  If not, write to
 the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
-#line 41 "./parse.y"
+#line 41 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 
 #include "funcdef.h"
 
@@ -111,9 +112,11 @@ typedef
 #endif
 #include <stdio.h>
 
+#ifndef __cplusplus
 #ifndef __STDC__
 #define const
 #endif
+#endif
 
 
 
@@ -163,8 +166,6 @@ static const short yyprhs[] = {     0,
    195,   197,   199,   201,   205,   207
 };
 
-#endif
-
 static const short yyrhs[] = {    42,
      0,     1,     0,    23,     0,    46,     0,    24,    38,    39,
      0,    25,    38,    42,    39,     0,    26,    38,    42,    40,
@@ -189,6 +190,8 @@ static const short yyrhs[] = {    42,
     45,    40,    44,     0,    20,     0,    22,     0
 };
 
+#endif
+
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
     86,    88,    94,    95,    96,    98,   102,   106,   110,   114,
@@ -388,7 +391,7 @@ static const short yycheck[] = {     0,
     14,    15,    16,    17
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-#line 3 "/afs/andrew/usr11/lord//lib/bison.simple"
+#line 3 "/usr/unsupported/lib/bison.simple"
 
 /* Skeleton output parser for bison,
    Copyright (C) 1984, 1989, 1990 Bob Corbett and Richard Stallman
@@ -412,7 +415,7 @@ static const short yycheck[] = {     0,
 #ifdef __GNUC__
 #define alloca __builtin_alloca
 #else /* not GNU C.  */
-#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc)
+#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi)
 #include <alloca.h>
 #else /* not sparc */
 #if defined (MSDOS) && !defined (__TURBOC__)
@@ -421,6 +424,16 @@ static const short yycheck[] = {     0,
 #if defined(_AIX)
 #include <malloc.h>
  #pragma alloca
+#else /* not MSDOS, __TURBOC__, or _AIX */
+#ifdef __hpux
+#ifdef __cplusplus
+extern "C" {
+void *alloca (unsigned int);
+};
+#else /* not __cplusplus */
+void *alloca ();
+#endif /* not __cplusplus */
+#endif /* __hpux */
 #endif /* not _AIX */
 #endif /* not MSDOS, or __TURBOC__ */
 #endif /* not sparc.  */
@@ -514,6 +527,11 @@ int yydebug;			/*  nonzero means print parse trace	*/
 #ifndef YYMAXDEPTH
 #define YYMAXDEPTH 10000
 #endif
+
+/* Prevent warning if -Wstrict-prototypes.  */
+#ifdef __GNUC__
+int yyparse (void);
+#endif
 
 #if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
 #define __yy_bcopy(FROM,TO,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
@@ -554,7 +572,7 @@ __yy_bcopy (char *from, char *to, int count)
 #endif
 #endif
 
-#line 169 "/afs/andrew/usr11/lord//lib/bison.simple"
+#line 184 "/usr/unsupported/lib/bison.simple"
 int
 yyparse()
 {
@@ -563,7 +581,7 @@ yyparse()
   register short *yyssp;
   register YYSTYPE *yyvsp;
   int yyerrstatus;	/*  number of tokens to shift before error messages enabled */
-  int yychar1;		/*  lookahead token as an internal (translated) token number */
+  int yychar1 = 0;		/*  lookahead token as an internal (translated) token number */
 
   short	yyssa[YYINITDEPTH];	/*  the state stack			*/
   YYSTYPE yyvsa[YYINITDEPTH];	/*  the semantic value stack		*/
@@ -642,13 +660,20 @@ yynewstate:
 #ifdef yyoverflow
       /* Each stack pointer address is followed by the size of
 	 the data in use in that stack, in bytes.  */
+#ifdef YYLSP_NEEDED
+      /* This used to be a conditional around just the two extra args,
+	 but that might be undefined if yyoverflow is a macro.  */
       yyoverflow("parser stack overflow",
 		 &yyss1, size * sizeof (*yyssp),
 		 &yyvs1, size * sizeof (*yyvsp),
-#ifdef YYLSP_NEEDED
 		 &yyls1, size * sizeof (*yylsp),
-#endif
 		 &yystacksize);
+#else
+      yyoverflow("parser stack overflow",
+		 &yyss1, size * sizeof (*yyssp),
+		 &yyvs1, size * sizeof (*yyvsp),
+		 &yystacksize);
+#endif
 
       yyss = yyss1; yyvs = yyvs1;
 #ifdef YYLSP_NEEDED
@@ -809,7 +834,8 @@ yydefault:
 /* Do a reduction.  yyn is the number of a rule to reduce with.  */
 yyreduce:
   yylen = yyr2[yyn];
-  yyval = yyvsp[1-yylen]; /* implement default value of the action */
+  if (yylen > 0)
+    yyval = yyvsp[1-yylen]; /* implement default value of the action */
 
 #if YYDEBUG != 0
   if (yydebug)
@@ -830,84 +856,84 @@ yyreduce:
   switch (yyn) {
 
 case 1:
-#line 87 "./parse.y"
+#line 87 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 { parse_return=yyvsp[0]; ;
     break;}
 case 2:
-#line 88 "./parse.y"
+#line 88 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		if(!parse_error)
 			parse_error=PARSE_ERR;
 		parse_return=0; ;
     break;}
 case 5:
-#line 96 "./parse.y"
+#line 96 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		yyval=yyvsp[-2]; ;
     break;}
 case 6:
-#line 98 "./parse.y"
+#line 98 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		(yyvsp[-3])->n_x.v_subs[0]=yyvsp[-1];
 		(yyvsp[-3])->n_x.v_subs[1]=(struct node *)0;
 		yyval=yyvsp[-3]; ;
     break;}
 case 7:
-#line 102 "./parse.y"
+#line 102 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		(yyvsp[-5])->n_x.v_subs[0]=yyvsp[-3];
 		(yyvsp[-5])->n_x.v_subs[1]=yyvsp[-1];
 		yyval=yyvsp[-5]; ;
     break;}
 case 8:
-#line 106 "./parse.y"
+#line 106 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		(yyvsp[-7])->n_x.v_subs[0]=make_list(yyvsp[-5],yyvsp[-3]);
  		(yyvsp[-7])->n_x.v_subs[1]=yyvsp[-1];
  		yyval=yyvsp[-7];;
     break;}
 case 9:
-#line 110 "./parse.y"
+#line 110 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		(yyvsp[-9])->n_x.v_subs[0]=make_list(yyvsp[-7],yyvsp[-5]);
  		(yyvsp[-9])->n_x.v_subs[1]=make_list(yyvsp[-3],yyvsp[-1]);
  		yyval=yyvsp[-9];;
     break;}
 case 10:
-#line 114 "./parse.y"
+#line 114 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		(yyvsp[-3])->n_x.v_subs[0]=(struct node *)0;
 		(yyvsp[-3])->n_x.v_subs[1]=yyvsp[-1];
 		yyval=yyvsp[-3]; ;
     break;}
 case 11:
-#line 118 "./parse.y"
+#line 118 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		yyvsp[-3]->n_x.v_subs[0]=yyvsp[-1];
 		yyval=yyvsp[-3]; ;
     break;}
 case 12:
-#line 121 "./parse.y"
+#line 121 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		yyvsp[-3]->n_x.v_subs[0]=yyvsp[-1];
 		yyval=yyvsp[-3]; ;
     break;}
 case 13:
-#line 125 "./parse.y"
+#line 125 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		yyvsp[-5]->n_x.v_subs[0]=yyvsp[-3];
 		yyvsp[-5]->n_x.v_subs[1]=yyvsp[-1];
 		yyval=yyvsp[-5]; ;
     break;}
 case 14:
-#line 129 "./parse.y"
+#line 129 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		yyvsp[-5]->n_x.v_subs[0]=yyvsp[-3];
 		yyvsp[-5]->n_x.v_subs[1]=yyvsp[-1];
 		yyval=yyvsp[-5]; ;
     break;}
 case 15:
-#line 135 "./parse.y"
+#line 135 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		if(yyvsp[-7]->comp_value!=F_INDEX)
 			parse_error=PARSE_ERR;
@@ -917,7 +943,7 @@ case 15:
 		yyval=yyvsp[-7]; ;
     break;}
 case 16:
-#line 142 "./parse.y"
+#line 142 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		if(yyvsp[-7]->comp_value!=F_INDEX)
 			parse_error=PARSE_ERR;
@@ -927,28 +953,28 @@ case 16:
 		yyval=yyvsp[-7]; ;
     break;}
 case 17:
-#line 150 "./parse.y"
+#line 150 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		(yyvsp[-7])->n_x.v_subs[0]=make_list(yyvsp[-5],yyvsp[-3]);
  		(yyvsp[-7])->n_x.v_subs[1]=yyvsp[-1];
  		yyval=yyvsp[-7];;
     break;}
 case 18:
-#line 154 "./parse.y"
+#line 154 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		(yyvsp[-7])->n_x.v_subs[0]=make_list(yyvsp[-5],yyvsp[-3]);
  		(yyvsp[-7])->n_x.v_subs[1]=yyvsp[-1];
  		yyval=yyvsp[-7];;
     break;}
 case 19:
-#line 159 "./parse.y"
+#line 159 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		(yyvsp[-3])->n_x.v_subs[0]=(struct node *)0;
 		(yyvsp[-3])->n_x.v_subs[1]=yyvsp[-1];
 		yyval=yyvsp[-3]; ;
     break;}
 case 20:
-#line 163 "./parse.y"
+#line 163 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		yyvsp[-3]->comp_value=IF;
 		yyvsp[-3]->n_x.v_subs[0]=yyvsp[-1];
@@ -958,98 +984,98 @@ case 20:
 		yyval=yyvsp[-3]; ;
     break;}
 case 21:
-#line 174 "./parse.y"
+#line 174 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 22:
-#line 178 "./parse.y"
+#line 178 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 23:
-#line 182 "./parse.y"
+#line 182 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 24:
-#line 186 "./parse.y"
+#line 186 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 25:
-#line 190 "./parse.y"
+#line 190 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 26:
-#line 194 "./parse.y"
+#line 194 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 27:
-#line 198 "./parse.y"
+#line 198 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 28:
-#line 202 "./parse.y"
+#line 202 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 29:
-#line 206 "./parse.y"
+#line 206 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 30:
-#line 210 "./parse.y"
+#line 210 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 31:
-#line 214 "./parse.y"
+#line 214 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 32:
-#line 218 "./parse.y"
+#line 218 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 33:
-#line 222 "./parse.y"
+#line 222 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[-2];
 		yyvsp[-1]->n_x.v_subs[1]=yyvsp[0];
 		yyval = yyvsp[-1]; ;
     break;}
 case 34:
-#line 226 "./parse.y"
+#line 226 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		if(yyvsp[0]->comp_value==CONST_FLT) {
 			yyvsp[0]->n_x.v_float= -(yyvsp[0]->n_x.v_float);
@@ -1067,53 +1093,53 @@ case 34:
 		} ;
     break;}
 case 35:
-#line 241 "./parse.y"
+#line 241 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		yyvsp[-1]->n_x.v_subs[0]=yyvsp[0];
 		yyvsp[-1]->n_x.v_subs[1]=(struct node *)0;
 		yyval = yyvsp[-1]; ;
     break;}
 case 36:
-#line 246 "./parse.y"
+#line 246 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 { yyval = yyvsp[-1]; ;
     break;}
 case 37:
-#line 247 "./parse.y"
+#line 247 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		if(!parse_error)
 			parse_error=NO_CLOSE;
 		;
     break;}
 case 38:
-#line 255 "./parse.y"
+#line 255 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 {
 		if(!parse_error)
 			parse_error=NO_CLOSE;
 		;
     break;}
 case 39:
-#line 263 "./parse.y"
+#line 263 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 { yyval = make_list(yyvsp[0], 0); ;
     break;}
 case 40:
-#line 265 "./parse.y"
+#line 265 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 { yyval = make_list(yyvsp[0], yyvsp[-2]); ;
     break;}
 case 43:
-#line 273 "./parse.y"
+#line 273 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 { yyval=make_list(yyvsp[0], 0); ;
     break;}
 case 44:
-#line 275 "./parse.y"
+#line 275 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 { yyval=make_list(yyvsp[0],yyvsp[-2]); ;
     break;}
 case 45:
-#line 279 "./parse.y"
+#line 279 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 { yyval=yyvsp[0]; ;
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 442 "/afs/andrew/usr11/lord//lib/bison.simple"
+#line 465 "/usr/unsupported/lib/bison.simple"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1183,7 +1209,9 @@ yyerrlab:   /* here on detecting error */
 	  int x, count;
 
 	  count = 0;
-	  for (x = 0; x < (sizeof(yytname) / sizeof(char *)); x++)
+	  /* Start X at -yyn if nec to avoid negative indexes in yycheck.  */
+	  for (x = (yyn < 0 ? -yyn : 0);
+	       x < (sizeof(yytname) / sizeof(char *)); x++)
 	    if (yycheck[x + yyn] == x)
 	      size += strlen(yytname[x]) + 15, count++;
 	  msg = (char *) malloc(size + 15);
@@ -1194,7 +1222,8 @@ yyerrlab:   /* here on detecting error */
 	      if (count < 5)
 		{
 		  count = 0;
-		  for (x = 0; x < (sizeof(yytname) / sizeof(char *)); x++)
+		  for (x = (yyn < 0 ? -yyn : 0);
+		       x < (sizeof(yytname) / sizeof(char *)); x++)
 		    if (yycheck[x + yyn] == x)
 		      {
 			strcat(msg, count == 0 ? ", expecting `" : " or `");
@@ -1306,7 +1335,7 @@ yyerrhandle:
   yystate = yyn;
   goto yynewstate;
 }
-#line 282 "./parse.y"
+#line 282 "/phydeaux/ni/lord/unsupported/oleo/parse.y"
 
 
 void
@@ -1845,7 +1874,7 @@ parse_cell_or_range FUN2(char **,ptr, struct rng *,retp)
 				} else if(retc) {
 					*ptr=p;
 					retp->lr=MIN_ROW;
-					retp->hr=MAX_COL;
+					retp->hr=MAX_ROW;
 					if((retc|COLREL)==(R_CELL|COLREL))
 						return (retc&COLREL) ? (RANGE|LCREL|HCREL) : RANGE;
 					else
