@@ -1,11 +1,12 @@
 
-/*  A Bison parser, made from ./posixtm.y  */
+/*  A Bison parser, made from /phydeaux/ni/lord/unsupported/oleo/posixtm.y with Bison version GNU Bison version 1.22
+  */
 
 #define YYBISON 1  /* Identify Bison output.  */
 
 #define	DIGIT	258
 
-#line 19 "./posixtm.y"
+#line 19 "/phydeaux/ni/lord/unsupported/oleo/posixtm.y"
 
 #ifdef __GNUC__
 #define alloca __builtin_alloca
@@ -60,9 +61,11 @@ typedef
 #endif
 #include <stdio.h>
 
+#ifndef __cplusplus
 #ifndef __STDC__
 #define const
 #endif
+#endif
 
 
 
@@ -106,13 +109,13 @@ static const short psxtprhs[] = {     0,
      0,     7,     9,    12,    13,    14,    17
 };
 
-#endif
-
 static const short psxtrhs[] = {     8,
      8,     8,     8,     6,     7,     0,     8,     0,     8,     8,
      0,     0,     0,     4,     8,     0,     3,     3,     0
 };
 
+#endif
+
 #if YYDEBUG != 0
 static const short psxtrline[] = { 0,
     56,    85,    92,    99,   110,   113,   122
@@ -161,7 +164,7 @@ static const short psxtcheck[] = {     2,
      4,     4,     5,     6,     3,     8,     9,     3,     0,     0
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-#line 3 "/afs/andrew/usr11/lord//lib/bison.simple"
+#line 3 "/usr/unsupported/lib/bison.simple"
 
 /* Skeleton output parser for bison,
    Copyright (C) 1984, 1989, 1990 Bob Corbett and Richard Stallman
@@ -185,7 +188,7 @@ static const short psxtcheck[] = {     2,
 #ifdef __GNUC__
 #define alloca __builtin_alloca
 #else /* not GNU C.  */
-#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc)
+#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi)
 #include <alloca.h>
 #else /* not sparc */
 #if defined (MSDOS) && !defined (__TURBOC__)
@@ -194,6 +197,16 @@ static const short psxtcheck[] = {     2,
 #if defined(_AIX)
 #include <malloc.h>
  #pragma alloca
+#else /* not MSDOS, __TURBOC__, or _AIX */
+#ifdef __hpux
+#ifdef __cplusplus
+extern "C" {
+void *alloca (unsigned int);
+};
+#else /* not __cplusplus */
+void *alloca ();
+#endif /* not __cplusplus */
+#endif /* __hpux */
 #endif /* not _AIX */
 #endif /* not MSDOS, or __TURBOC__ */
 #endif /* not sparc.  */
@@ -287,6 +300,11 @@ int psxtdebug;			/*  nonzero means print parse trace	*/
 #ifndef YYMAXDEPTH
 #define YYMAXDEPTH 10000
 #endif
+
+/* Prevent warning if -Wstrict-prototypes.  */
+#ifdef __GNUC__
+int psxtparse (void);
+#endif
 
 #if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
 #define __psxt_bcopy(FROM,TO,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
@@ -327,7 +345,7 @@ __psxt_bcopy (char *from, char *to, int count)
 #endif
 #endif
 
-#line 169 "/afs/andrew/usr11/lord//lib/bison.simple"
+#line 184 "/usr/unsupported/lib/bison.simple"
 int
 psxtparse()
 {
@@ -336,7 +354,7 @@ psxtparse()
   register short *psxtssp;
   register YYSTYPE *psxtvsp;
   int psxterrstatus;	/*  number of tokens to shift before error messages enabled */
-  int psxtchar1;		/*  lookahead token as an internal (translated) token number */
+  int psxtchar1 = 0;		/*  lookahead token as an internal (translated) token number */
 
   short	psxtssa[YYINITDEPTH];	/*  the state stack			*/
   YYSTYPE psxtvsa[YYINITDEPTH];	/*  the semantic value stack		*/
@@ -415,13 +433,20 @@ psxtnewstate:
 #ifdef psxtoverflow
       /* Each stack pointer address is followed by the size of
 	 the data in use in that stack, in bytes.  */
+#ifdef YYLSP_NEEDED
+      /* This used to be a conditional around just the two extra args,
+	 but that might be undefined if psxtoverflow is a macro.  */
       psxtoverflow("parser stack overflow",
 		 &psxtss1, size * sizeof (*psxtssp),
 		 &psxtvs1, size * sizeof (*psxtvsp),
-#ifdef YYLSP_NEEDED
 		 &psxtls1, size * sizeof (*psxtlsp),
-#endif
 		 &psxtstacksize);
+#else
+      psxtoverflow("parser stack overflow",
+		 &psxtss1, size * sizeof (*psxtssp),
+		 &psxtvs1, size * sizeof (*psxtvsp),
+		 &psxtstacksize);
+#endif
 
       psxtss = psxtss1; psxtvs = psxtvs1;
 #ifdef YYLSP_NEEDED
@@ -582,7 +607,8 @@ psxtdefault:
 /* Do a reduction.  psxtn is the number of a rule to reduce with.  */
 psxtreduce:
   psxtlen = psxtr2[psxtn];
-  psxtval = psxtvsp[1-psxtlen]; /* implement default value of the action */
+  if (psxtlen > 0)
+    psxtval = psxtvsp[1-psxtlen]; /* implement default value of the action */
 
 #if YYDEBUG != 0
   if (psxtdebug)
@@ -603,7 +629,7 @@ psxtreduce:
   switch (psxtn) {
 
 case 1:
-#line 62 "./posixtm.y"
+#line 62 "/phydeaux/ni/lord/unsupported/oleo/posixtm.y"
 {
 	         if (psxtvsp[-5] >= 1 && psxtvsp[-5] <= 12)
 		   t.tm_mon = psxtvsp[-5] - 1;
@@ -628,7 +654,7 @@ case 1:
 	       ;
     break;}
 case 2:
-#line 85 "./posixtm.y"
+#line 85 "/phydeaux/ni/lord/unsupported/oleo/posixtm.y"
 {
                    t.tm_year = psxtvsp[0];
 		   /* Deduce the century based on the year.
@@ -638,7 +664,7 @@ case 2:
 		 ;
     break;}
 case 3:
-#line 92 "./posixtm.y"
+#line 92 "/phydeaux/ni/lord/unsupported/oleo/posixtm.y"
 {
                             t.tm_year = psxtvsp[-1] * 100 + psxtvsp[0];
 			    if (t.tm_year < 1900) {
@@ -648,7 +674,7 @@ case 3:
 			  ;
     break;}
 case 4:
-#line 99 "./posixtm.y"
+#line 99 "/phydeaux/ni/lord/unsupported/oleo/posixtm.y"
 {
                     time_t now;
 		    struct tm *tmp;
@@ -660,13 +686,13 @@ case 4:
 		  ;
     break;}
 case 5:
-#line 110 "./posixtm.y"
+#line 110 "/phydeaux/ni/lord/unsupported/oleo/posixtm.y"
 {
                         t.tm_sec = 0;
 		      ;
     break;}
 case 6:
-#line 113 "./posixtm.y"
+#line 113 "/phydeaux/ni/lord/unsupported/oleo/posixtm.y"
 {
 	                  if (psxtvsp[0] >= 0 && psxtvsp[0] <= 61)
 			    t.tm_sec = psxtvsp[0];
@@ -676,14 +702,14 @@ case 6:
 			;
     break;}
 case 7:
-#line 122 "./posixtm.y"
+#line 122 "/phydeaux/ni/lord/unsupported/oleo/posixtm.y"
 {
                           psxtval = psxtvsp[-1] * 10 + psxtvsp[0];
 			;
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 442 "/afs/andrew/usr11/lord//lib/bison.simple"
+#line 465 "/usr/unsupported/lib/bison.simple"
 
   psxtvsp -= psxtlen;
   psxtssp -= psxtlen;
@@ -753,7 +779,9 @@ psxterrlab:   /* here on detecting error */
 	  int x, count;
 
 	  count = 0;
-	  for (x = 0; x < (sizeof(psxttname) / sizeof(char *)); x++)
+	  /* Start X at -psxtn if nec to avoid negative indexes in psxtcheck.  */
+	  for (x = (psxtn < 0 ? -psxtn : 0);
+	       x < (sizeof(psxttname) / sizeof(char *)); x++)
 	    if (psxtcheck[x + psxtn] == x)
 	      size += strlen(psxttname[x]) + 15, count++;
 	  msg = (char *) malloc(size + 15);
@@ -764,7 +792,8 @@ psxterrlab:   /* here on detecting error */
 	      if (count < 5)
 		{
 		  count = 0;
-		  for (x = 0; x < (sizeof(psxttname) / sizeof(char *)); x++)
+		  for (x = (psxtn < 0 ? -psxtn : 0);
+		       x < (sizeof(psxttname) / sizeof(char *)); x++)
 		    if (psxtcheck[x + psxtn] == x)
 		      {
 			strcat(msg, count == 0 ? ", expecting `" : " or `");
@@ -876,7 +905,7 @@ psxterrhandle:
   psxtstate = psxtn;
   goto psxtnewstate;
 }
-#line 126 "./posixtm.y"
+#line 126 "/phydeaux/ni/lord/unsupported/oleo/posixtm.y"
 
 static int
 psxtlex ()
