@@ -1,3 +1,4 @@
+/* Postscript printing of spreadsheets */
 /*	Copyright (C) 1992, 1993 Free Software Foundation, Inc.
 
 This program is free software; you can redistribute it and/or modify
@@ -22,12 +23,14 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #include "cmd.h"
 #include "io-generic.h"
 #include "io-abstract.h"
+#include "print.h"
 
 
 
 #ifdef __STDC__
 static void 
-put_eps_header (struct display *dpy, float scale, float wid, float hgt, FILE *fp)
+put_eps_header (struct display *dpy,
+		float scale, float wid, float hgt, FILE *fp)
 #else
 static void 
 put_eps_header (dpy, scale, wid, hgt, fp)
@@ -120,7 +123,7 @@ psprint_region (fp, rng, wid, hgt, font)
   fprintf (fp, "/Cols	   %d def\n", cols);
   fprintf (fp, "/Rows      %d def\n", rows);
   fprintf (fp, "%% The scale is just the point size of the default font. \n");
-  fprintf (fp, "%% The value here is just an initial approximation.  The real value\n");
+  fprintf (fp, "%% The value here is just approximate.  The real value\n");
   fprintf (fp, "%% is computed below.\n");
   fprintf (fp, "/Scale     %f def\n", scale);
   fprintf (fp, "/PointsWide CharsWide Scale mul def\n");
@@ -145,7 +148,8 @@ psprint_region (fp, rng, wid, hgt, font)
   fprintf (fp, "/SizeDir 1 def\n");
   fprintf (fp, "{ \n");
   fprintf (fp, "  DefaultFontSize 4 le { exit } if\n");
-  fprintf (fp, "  /DefaultFont BasicDefaultFont DefaultFontSize scalefont def\n");
+  fprintf (fp, "  /DefaultFont BasicDefaultFont DefaultFontSize \n");
+  fprintf (fp, "    scalefont def\n");
   fprintf (fp, "  DefaultFont setfont \n");
   fprintf (fp, "  DefaultFont font-box\n");
   fprintf (fp, "  Scale le exch Scale le and not\n");
@@ -153,7 +157,8 @@ psprint_region (fp, rng, wid, hgt, font)
   fprintf (fp, "  /DefaultFontSize DefaultFontSize SizeDir add def\n");
   fprintf (fp, "} loop\n");
   fprintf (fp, "/DefaultFontSize DefaultFontSize def\n");
-  fprintf (fp, "/DefaultFont BasicDefaultFont DefaultFontSize scalefont def\n");
+  fprintf (fp, "/DefaultFont BasicDefaultFont DefaultFontSize \n");
+  fprintf (fp, "  scalefont def\n");
   fprintf (fp, "/Scale DefaultFontSize def\n");
   fprintf (fp, "\n");
   fprintf (fp, "DefaultFont font-box\n");
@@ -182,19 +187,19 @@ psprint_region (fp, rng, wid, hgt, font)
 	  if (cd->unclipped)
 	    fprintf (fp, "%d %d setused\n", ri, ci);
 	}
-    fprintf (fp, "/Rowy [ ");
+    fprintf (fp, "/Rowy [ \n");
     for (ri = 0; ri < rows; ++ri)
-      fprintf (fp, "%d ", dpy.rowy[ri]);
-    fprintf (fp, "] def\n/Colx [ ");
+      fprintf (fp, "  %d\n", dpy.rowy[ri]);
+    fprintf (fp, "] def\n/Colx [\n");
     for (ci = 0; ci < cols; ++ci)
-      fprintf (fp, "%d ", dpy.colx[ci]);
+      fprintf (fp, "  %d\n", dpy.colx[ci]);
     fprintf (fp, "] def\n");
-    fprintf (fp, "/Heights [ ");
+    fprintf (fp, "/Heights [\n");
     for (ri = 0; ri < rows; ++ri)
-      fprintf (fp, "%d ", dpy.heights[ri]);
-    fprintf (fp, "] def\n/Widths [ ");
+      fprintf (fp, "  %d\n", dpy.heights[ri]);
+    fprintf (fp, "] def\n/Widths [\n");
     for (ci = 0; ci < cols; ++ci)
-      fprintf (fp, "%d ", dpy.widths[ci]);
+      fprintf (fp, "  %d\n", dpy.widths[ci]);
     fprintf (fp, "] def\n");
   }
   fprintf (fp, "\n");
@@ -206,10 +211,12 @@ psprint_region (fp, rng, wid, hgt, font)
   fprintf (fp, "/from-oleo-matrix to-oleo-matrix matrix invertmatrix def\n");
   fprintf (fp, "\n");
   fprintf (fp, "/rc-to-oleo-xy { Colx exch gget exch Rowy exch gget } def\n");
-  fprintf (fp, "/rc-to-oleo-wh { Widths exch gget exch Heights exch gget } def\n");
+  fprintf (fp, "/rc-to-oleo-wh \n");
+  fprintf (fp, "  { Widths exch gget exch Heights exch gget } def\n");
   fprintf (fp, "/oleo-xy-to-ps { from-oleo-matrix transform } def\n");
   fprintf (fp, "/rc-to-xy { rc-to-oleo-xy oleo-xy-to-ps } def\n");
-  fprintf (fp, "/rc-to-wh { rc-to-oleo-wh Scaleh mul exch Scalew mul exch } def\n");
+  fprintf (fp, "/rc-to-wh \n");
+  fprintf (fp, "  { rc-to-oleo-wh Scaleh mul exch Scalew mul exch } def\n");
   fprintf (fp, "/oleo-box-to-ps\n");
   fprintf (fp, "{ \n");
   fprintf (fp, "  dup dup 0 gget exch 1 gget oleo-xy-to-ps\n");
@@ -226,9 +233,11 @@ psprint_region (fp, rng, wid, hgt, font)
   fprintf (fp, "  5 -1 roll dup 0 lt \n");
   fprintf (fp, "  { pop }  %% str r c xstr ycel\n");
   fprintf (fp, "  { 0 eq 	    %% str r c xcel ycel bool\n");
-  fprintf (fp, "    Widths 4 index gget Scalew mul exch  %% str r c xcel ycel wcell bool\n");
+  fprintf (fp, "    Widths 4 index gget Scalew mul exch \n");
+  fprintf (fp, "    %% str r c xcel ycel wcell bool\n");
   fprintf (fp, "    { cell-goal-w sub 2 div 3 -1 roll add exch }\n");
-  fprintf (fp, "    { 2 index add cell-goal-w sub 3 -1 roll pop exch } ifelse \n");
+  fprintf (fp, "    { 2 index add cell-goal-w sub 3 -1 roll pop exch } \n");
+  fprintf (fp, "    ifelse \n");
   fprintf (fp, "    %% str r c xstr ycel \n");
   fprintf (fp, " } ifelse      \n");
   fprintf (fp, " %% str r c xstr ycel \n");
@@ -249,7 +258,8 @@ psprint_region (fp, rng, wid, hgt, font)
   fprintf (fp, "  layout_answer 0 gget	\n");
   fprintf (fp, "  {\n");
   fprintf (fp, "    dup 0 eq { exit } if\n");
-  fprintf (fp, "    dup Colx exch gget Scalew mul layout_goal 0 gget le { exit } if\n");
+  fprintf (fp, "    dup Colx exch gget Scalew mul layout_goal 0 gget le \n");
+  fprintf (fp, "    { exit } if\n");
   fprintf (fp, "    1 sub\n");
   fprintf (fp, "  } loop\n");
   fprintf (fp, "  layout_answer exch 0 exch put\n");
@@ -257,7 +267,8 @@ psprint_region (fp, rng, wid, hgt, font)
   fprintf (fp, "  layout_answer 1 gget	\n");
   fprintf (fp, "  {\n");
   fprintf (fp, "    dup 0 eq { exit } if\n");
-  fprintf (fp, "    dup Rowy exch gget Scaleh mul layout_goal 1 gget le { exit } if\n");
+  fprintf (fp, "    dup Rowy exch gget Scaleh mul layout_goal 1 gget le \n");
+  fprintf (fp, "    { exit } if\n");
   fprintf (fp, "    1 sub\n");
   fprintf (fp, "  } loop\n");
   fprintf (fp, "  layout_answer exch 3 exch put\n");
@@ -265,16 +276,19 @@ psprint_region (fp, rng, wid, hgt, font)
   fprintf (fp, "  layout_answer 2 gget	\n");
   fprintf (fp, "  {\n");
   fprintf (fp, "    dup Cols 1 sub eq { exit } if\n");
-  fprintf (fp, "    dup dup Colx exch gget exch Widths exch gget add Scalew mul\n");
+  fprintf (fp, "    dup dup Colx exch gget exch Widths exch \n");
+  fprintf (fp, "    gget add Scalew mul\n");
   fprintf (fp, "    layout_goal 2 gget gt { exit } if\n");
   fprintf (fp, "    1 add \n");
   fprintf (fp, "  } loop\n");
   fprintf (fp, "  layout_answer exch 2 exch put\n");
   fprintf (fp, "\n");
   fprintf (fp, "  layout_answer dup 0 gget exch 1 gget \n");
-  fprintf (fp, "  layout_answer exch 0 exch put layout_answer exch 1 exch put\n");
+  fprintf (fp, "  layout_answer exch 0 exch put \n");
+  fprintf (fp, "  layout_answer exch 1 exch put\n");
   fprintf (fp, "  layout_answer dup 2 gget exch 3 gget \n");
-  fprintf (fp, "  layout_answer exch 2 exch put layout_answer exch 3 exch put\n");
+  fprintf (fp, "  layout_answer exch 2 exch put\n");
+  fprintf (fp, "  layout_answer exch 3 exch put\n");
   fprintf (fp, "  layout_answer 1 gget 1 layout_answer 3 gget\n");
   fprintf (fp, "  {\n");
   fprintf (fp, "    /layout_ct fed\n");
@@ -284,13 +298,16 @@ psprint_region (fp, rng, wid, hgt, font)
   fprintf (fp, "       layout_rt layout_ct checkused \n");
   fprintf (fp, "	{\n");
   fprintf (fp, "	  layout_ct layout_c lt\n");
-  fprintf (fp, "	    { layout_ct 1 add layout_answer 1 gget max layout_answer exch 1 exch put }\n");
+  fprintf (fp, "	    { layout_ct 1 add layout_answer \n");
+  fprintf (fp, "	      1 gget max layout_answer exch 1 exch put }\n");
   fprintf (fp, "	    if\n");
   fprintf (fp, "	  layout_ct layout_c gt\n");
-  fprintf (fp, "	    { layout_ct 1 sub layout_answer 3 gget min layout_answer exch 3 exch put }\n");
+  fprintf (fp, "	    { layout_ct 1 sub layout_answer\n");
+  fprintf (fp, "	      3 gget min layout_answer exch 3 exch put }\n");
   fprintf (fp, "	    if\n");
   fprintf (fp, "	  layout_rt layout_r lt\n");
-  fprintf (fp, "	    { layout_rt 1 add layout_answer 0 gget max layout_answer exch 0 exch put }\n");
+  fprintf (fp, "	    { layout_rt 1 add layout_answer 0 \n");
+  fprintf (fp, "	      gget max layout_answer exch 0 exch put }\n");
   fprintf (fp, "	    if\n");
   fprintf (fp, "	} if\n");
   fprintf (fp, "     } for\n");
