@@ -1652,11 +1652,14 @@ finish_shift_var (name, v)
 #endif
 {
   int n;
-  if (!v->var_ref_fm || v->var_flags != VAR_DANGLING_RANGE)
+  if (v->var_flags != VAR_DANGLING_RANGE)
     return;
-
+  
   v->var_flags = VAR_RANGE;
 
+  if (!v->var_ref_fm)
+    return;
+
   for (n = 0; n < v->var_ref_fm->refs_used; n++)
     {
       cur_row = v->var_ref_fm->fm_refs[n].ref_row;
