@@ -19,8 +19,8 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
 
 
-
 #include <sys/types.h>
+
 #ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
 #endif
@@ -38,6 +38,7 @@ extern int getuid (void);
 #endif
 #endif /* HAVE_UNISTD_H */
 
+#ifndef _DEBUG_MALLOC_INC
 #if defined(STDC_HEADERS) || defined(HAVE_STRING_H)
 #include <string.h>
 /* An ANSI string.h and pre-ANSI memory.h might conflict.  */
@@ -63,6 +64,7 @@ extern int getuid (void);
 #include <strings.h>
 /* memory.h and strings.h conflict on some systems.  */
 #endif /* not STDC_HEADERS and not HAVE_STRING_H */
+#endif /* _DEBUG_MALLOC_INC */
 
 
 #ifdef STDC_HEADERS
@@ -110,6 +112,7 @@ extern int atoi (const char *);
 #endif
 extern char *getenv (const char *);
 
+#ifndef _DEBUG_MALLOC_INC
 #ifndef HAVE_STRDUP
 extern char *strdup (const char *);
 #endif
@@ -122,15 +125,18 @@ extern int strincmp (const char *, const char *, size_t);
 #ifndef HAVE_STRSTR
 extern char *strstr (const char *, const char *);
 #endif
+#endif /* _DEBUG_MALLOC_INC */
 
 #else  /* !defined(__STDC__) */
 
+#ifndef _DEBUG_MALLOC_INC
 #ifndef HAVE_STRDUP
 extern char *strdup ();
 #endif
 #ifndef HAVE_STRSTR
 extern char *strstr ();
 #endif
+#endif /* _DEBUG_MALLOC_INC */
 
 #endif /* !defined(__STDC__) */
 
