@@ -53,6 +53,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #define _IOSTRG 0
 #endif
 
+#ifndef _DEBUG_MALLOC_INC
 #ifdef __STDC__
 extern void abort (void);
 extern void *malloc (size_t);
@@ -64,6 +65,7 @@ extern void *malloc ();
 extern void *calloc ();
 extern void *realloc ();
 #endif
+#endif /* _DEBUG_MALLOC_INC */
 
 extern int sys_nerr;
 extern char *sys_errlist[];
@@ -628,6 +630,7 @@ strdup (str)
 }
 #endif
 
+#ifndef _DEBUG_MALLOC_INC
 #ifndef HAVE_STRICMP
 /*
  * stricmp - compare string s1 to s2, ignoring case
@@ -673,7 +676,9 @@ stricmp (s1, s2)
     return chr1 - chr2;
 }
 #endif
+#endif /* ndef _DEBUG_MALLOC_INC */
 
+#ifndef _DEBUG_MALLOC_INC
 #ifndef HAVE_STRINCMP
 /* strincmp - compare first N chars of strings S1 and S2 */
 #ifdef __STDC__
@@ -722,7 +727,9 @@ strincmp (s1, s2, n)
     return chr1 - chr2;
 }
 #endif
+#endif /* ndef _DEBUG_MALLOC_INC */
 
+#ifndef _DEBUG_MALLOC_INC
 #ifndef HAVE_STRSTR
 #ifdef __STDC__
 char *
@@ -751,6 +758,7 @@ strstr (s, wanted)
   return scan;
 }
 #endif
+#endif /* ndef _DEBUG_MALLOC_INC */
 
 #ifdef __STDC__
 char *
