@@ -20,16 +20,13 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #include "sysdef.h"
 
 #ifdef __STDC__
-#define CONST const
 #undef NULL
-#else
-#define CONST
 #endif
 
 int
 vfprintf (fp, s, ap)
      FILE *fp;
-     CONST char *s;
+     const char *s;
      va_list ap;
 {
   int len;
